
 * Open the act23data.dta file

 * Stacking data for XTMIXED (wide to long)
 * list time-varying variables first, i(level2ID) j(newtimeID)
 reshape long severity stress, i(PersonID) j(month)

 * Labeling newly created stacked variables
label variable month  "Month of Study (1 to 5)"
label variable severity "Time-Varying Severity Outcome"
label variable stress "Time-Varying Stress Predictor"

 * Centering time at first occasion
gen month1 = month - 1
gen month1sq = month1 * month1
label variable month1 "Linear Month of Study (0=1)"
label variable month1sq "Quadratic Month of Study (0=1)"

 * Getting person mean stress (for use in activity 3)
egen PMstress = mean(stress), by(PersonID)
label variable PMstress "Person Mean Stress"
 
 * You can add the rest of your centered variables for activity 3 here
 

///////////////////////////////////////////////////////////////////////////////////////
// xtmixed DV fixed effects, FE options || Level2ID: random effects, RE options ///
//	  variance reml/mle covariance(Gmatrix type) residuals(Rmatrix type), t(Level1ID),
//	  estat ic n(#persons),
//    estimates store ModelName,  
// 	  lrtest BiggerModel SmallerModel
///////////////////////////////////////////////////////////////////////////////////////

 * STATA Empty Means, Random Intercept Model
xtmixed severity ,  || PersonID:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(month)), 
	estat ic, n(200),
	estat recovariance, level(PersonID)

 * Now it is your turn!
 
 * 1: Empty Model and ICC (=.41)
 * STATA Empty Means, Random Intercept Model
xtmixed severity ,  || PersonID:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(month)), 
	estat ic, n(200),
	estat recovariance, level(PersonID)
 
 * 2: Saturated means, unstructured R matrix model
 ***  Means are declining over time, which is informative for fixed effects
 *** Variances and covariances decrease, then increase over time
 *** Informative for what kind of variance model we'll need
xtmixed severity ib(last).month, || PersonID: , noconstant /// 
	variance reml residuals(unstructured, t(month)),
	estat ic, n(200)
	margins i.month

 * 3: Polynomial fixed and random effects models	
	
 * STATA Fixed Linear Time, Random Intercept Model
 * P-value for month1 is signif, so model fits better
xtmixed severity c.month1,  || PersonID:  ,  /// 
	variance reml covariance(unstructured) residuals(independent,t(month)), 
	estat ic, n(200),
	estat recovariance, level(PersonID)
	estimates store FixLin

 * STATA Random Linear Time Model
 * REML deviance difference for df=2 is signif, so model fits better
xtmixed severity c.month1,  || PersonID: month1 ,  ///  
	variance reml covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID),
	estimates store RandLin,
	lrtest RandLin FixLin

 * STATA Fixed Quadratic, Random Linear Time Model
 * P-value for month1sq is NOT signif, so model does not fit better
xtmixed severity c.month1 c.month1sq,  || PersonID: month1 ,  /// 
	variance reml covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID),
	estimates store FixQuad

 * STATA Random Quadratic Time Model
 * REML deviance difference for df=3 is signif, so model fits better
xtmixed severity c.month1 c.month1sq,  || PersonID: month1 month1sq,  /// 
	variance reml covariance(un) residuals(independent,t(month)),  
	estat ic, n(101), 
	estat recovariance, level(PersonID),
	estimates store RandQuad,
	lrtest RandQuad FixQuad,
	lincom 1*_cons + 0*month1   + 0*month1sq    // intercept at month 1
	lincom 1*_cons + 1*month1   + 1*month1sq    // intercept at month 2
	lincom 1*_cons + 2*month1   + 4*month1sq    // intercept at month 3
	lincom 1*_cons + 3*month1   + 9*month1sq	// intercept at month 4
	lincom 1*_cons + 4*month1   + 16*month1sq	// intercept at month 5
	lincom 1*month1 + 0*month1sq     // linear slope at month 1
	lincom 1*month1 + 2*month1sq     // linear slope at month 2
	lincom 1*month1 + 4*month1sq     // linear slope at month 3
	lincom 1*month1 + 6*month1sq     // linear slope at month 4
	lincom 1*month1 + 8*month1sq     // linear slope at month 5
	
/* 4: Interpretation of final random quadratic model:

Calculating 95% random effects confidence intervals to interpret variance components:
CI = fixed effect  2*SQRT(variance)
Intercept CI = 			15.849  2*SQRT(9.433)   9.71 to 21.99
Linear Slope CI =		 -.716  2*SQRT(2.587) 	-3.93 to 2.50
Quadratic Slope CI =	  .052  2*SQRT(.134) 	-0.68 to 0.78

Summary of Final Model Parameters: 
The average expected value of Y at the first occasion (because month is centered at 1) is 15.849, 
and this is expected to fall between 9.71 and 21.99 for 95% of the individuals in the sample. 
There is a significant instantaneous linear rate of decline of -.716/month as evaluated at the 
first occasion, and this linear effect of time varies significantly over individuals. 
Specifically, the linear slope is predicted to fall between -3.93 and 2.50 for 
95% of the individuals in the sample. so not everyone is predicted to decline 
(as evaluated at the first occasion). 
Although the average deceleration in the linear rate of decline of .052/month is not significant, 
significant individual differences were found, such that the 95% confidence interval for the 
quadratic effect of time was -.68 to .78. Thus, individuals are predicted to demonstrate both 
acceleration and deceleration of the initial negative trend. The interpretation of the 
quadratic coefficient is such that for every additional month, the linear coefficient 
of -.716 becomes .104 less negative 
(quadratic coefficient * 2 describes how the linear trend changes per unit time).
*/
