* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for files to be saved - CHANGE THESE TO YOUR DIRECTORIES;
LIBNAME activity "F:\12_ICPSR\ICPSR_2012_Download\Activities\Act23";


* Importing SAS dataset into work library;
DATA work.act23data; SET activity.act23data;
	* Computing person mean stress to use as predictor;
	pmstress = MEAN(OF stress1-stress5);
	* Stacking data; 
	month=1; severity=severity1; stress=stress1; OUTPUT;
	month=2; severity=severity2; stress=stress2; OUTPUT;
	month=3; severity=severity3; stress=stress3; OUTPUT;
	month=4; severity=severity4; stress=stress4; OUTPUT;
	month=5; severity=severity5; stress=stress5; OUTPUT;
	* Labeling all predictors;
	LABEL 	PersonID = 	"PersonID: Unique Identifier"
			baseage = 	"baseage: Age at Baseline"
			treat = 	"treat: Treatment Group (1=control, 2=treat)"
			month =	 	"month: Month of Study"
			severity = 	"severity: Time-Varying Severity Outcome"
			stress =	"stress: Time-Varying Stress Predictor"
			pmstress = 	"pmstress: Person-Mean Stress Predictor";
	* Dropping unnecessary multivariate variables;
	DROP severity1-severity5 stress1-stress5;
RUN;

* Creating and centering predictor variables for analysis;
DATA work.act23data; SET work.act23data;
	* Selecting only complete cases;
	WHERE NMISS(baseage, treat, stress)=0;
	* Your predictor centering code goes here -- make sure to add labels;
	month1 = month - 1; 
	month5 = month - 5;
		LABEL month1 = "month1: Month Centered at 1"
			  month5 = "month5: Month Centered at 5";
	* ADD YOUR SYNTAX FOR CENTERING PREDICTORS IN ACTIVITY 3 HERE;
	age40 = baseage - 40; 	
		LABEL age40 = "age40: Age at Baseline (0=40)";
	     IF treat=1 THEN DO; treat0=0; treat1=1; END;
	ELSE IF treat=2 THEN DO; treat0=1; treat1=0; END;	
		LABEL treat0 = "treat0: Treatment Group (0=C, 1=T)"
		  	  treat1 = "treat1: Control Group (0=T, 1=C)";
	PMstress5 = pmstress - 5;
	WPstress = stress - pmstress;
	TVstress5 = stress - 5;
		LABEL PMstress5 = "PMstress5: Person-Mean Stress (0=5)"
			  WPstress  = "WPStress: Within-Person Stress (0=PM)"
			  TVstress5 = "TVstress5: Time-Varying Stress (0=5)";
RUN;

* Baseline unconditional model;
TITLE "Random Quadratic Unconditional Baseline Model";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;

* 1: Effects of age:
	 Main effect of age --> effect on severity at month1=0
	 Age*month1 --> effect on linear slope for month
	 Age*month1*month1 --> effect on quadratic slope for month;

TITLE "Add 3 Effects of age";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40 month1*age40 month1*month1*age40 
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;
TITLE "Drop age by quadratic month";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40 month1*age40 
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;
TITLE "Drop age by linear month - final age model";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;

* 2: Effects of group:
	 First estimate using control group as a reference;
TITLE "Control group full model";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
					 treat0 month1*treat0 month1*month1*treat0
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;
TITLE "Drop control group by quadratic month";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
					 treat0 month1*treat0
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;
* a: Control group did change significantly over time --> month1 effect
  b: (don't know yet)
  c: Treatment group decline more --> treat0*month1 effect
  d: No difference between groups in severity at month1=0 --> treat0 effect
  e: (don't know yet);

* Now re-estimating model using treatment and month=5 as reference to get b and e;
TITLE "Previous model, new reference point for month and group";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month5 month5*month5 
					 age40  
					 treat1 month5*treat1
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month5 month5*month5 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;
* a: (from previous model)
  b: Treatment group did change significantly over time --> month1 effect
  c: (from previous model, just backwards)
  d: (from previous model)
  e:  Treatment is significantly lower in severity at month5=0 --> treat0 effect;


* 3:ICC for Stress (=.70);
TITLE "Random Intercept Only Baseline Model (equal to Compound Symmetry)";		
PROC MIXED DATA=act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;	
  	MODEL stress =  / SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=PersonID;	
  	REPEATED month / R RCORR TYPE=VC SUBJECT=PersonID;
RUN;


* 4: Effects of stress:
     First estimate using person-mean-centering for stress;
TITLE "PMC stress model";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
					 treat0 month1*treat0
					 pmstress5 wpstress
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
	ESTIMATE "Contextual Effect"	pmstress5 1 wpstress -1;
RUN;
* a: Greater person mean stress predicts greater mean severity --> pmstress5 effect
  b: More stress than usual sort of predicts more severity than usual --> wpstress effect
  c: (don't know yet, but could get via ESTIMATE statement as shown);

* Re-estimate model using grand-mean-centering for stress to get (c);
TITLE "GMC stress model";
PROC MIXED DATA=work.act23data NOCLPRINT NOITPRINT COVTEST METHOD=ML;
	CLASS PersonID month;
	MODEL severity = month1 month1*month1 
					 age40  
					 treat0 month1*treat0
					 pmstress5 tvstress5
						/ SOLUTION DDFM=SATTERTHWAITE;
	RANDOM INTERCEPT month1 month1*month1 / SUBJECT=PersonID TYPE=UN;
	REPEATED month / SUBJECT=PersonID TYPE=VC;
RUN;
* c: Is additional impact of pmstress after controlling for current stress --> pmstress5 effect;



