*******************************************************************************
*******						SAS SYNTAX RULES							*******
******************************************************************************;

* Each command must end with a semi-colon;

/* You can comment like this for large chunks of code */

* Or you can comment line by line as needed;

/* 	USE COLORS TO HELP YOU!
	Comments are GREEN 
   	SAS system commands are BLUE
   	Libraries and Labels are PURPLE
		-- anything in PURPLE is case-sensitive and space-sensitive
   	Variables and file names are BLACK
   	Entered data should be shaded YELLOW
   	If you see RED, something is wrong 
   	SAS is NOT case-sensitive except in titles and labels */
   

/* Setting global system options for formatting output:
	center/nocenter, date/nodate, number/nonumber for output pages,
	linesize = number of lines across (64-256 or MAX), 
	pagesize = #lines per page (15-32767 or MAX),
	formdlim = ' ' eliminates page breaks in output, 
			 = '' to put them back
			 = '-' puts a line between outputs  (can use with any character) 
    Initial TITLE shuts off annoying SAS default headers */

	OPTIONS nocenter nodate nonumber linesize=120 pagesize=MAX formdlim='-';
	TITLE;

/*  Titles stay in effect until next one or until just TITLE. 
	You can use single or double quotes, but double are more versatile */

	TITLE1 "This is my first title";
	TITLE2 "This is my second title";	* Can have up to 9 titles;
	TITLE1; TITLE2;		* Previous titles are now shut off;
	

*******************************************************************************
****** 				Importing, Saving, and Exporting Data Files			 ******
******************************************************************************;

/* A LIBRARY is name for a specific FOLDER (not a file) location on your computer
   LIBRARY names must be 8 characters or less, with no special characters
   Once you have defined a library using a LIBNAME staement, you can access 
   existing SAS data sets or save newly created data sets to a permanent file */

* I have named my library "filepath";
	LIBNAME filepath "F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1";

/* Importing SAS data requires a library, but importing any other kind of data
	requires an exact file path. To make it easier on ourselves, we use use a 
	programming trick -- a macro variable that functions like a library for use
	in importing non-SAS files as follows: */

/* Importing SAS data requires a library, but importing any other kind of data
	requires an exact file path. To make it easier on ourselves, we use use a 
	programming trick -- a macro variable that functions like a library for use
	in importing non-SAS files as follows: */
* %LET statement defines a global placeholder for the file path;
* The "&filepath." statement then abbreviates that place;
	%LET filepath = F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1;
	LIBNAME filepath "&filepath."; 


*********************************************
***   Reading in existing SAS datasets    ***
*********************************************;

/* It is a REALLY GOOD IDEA to immediately copy whatever file you
   will be working with to the "work" library, which is a temporary location
   DATA creates a new SAS data set in the work library called "datafilename"
   FROM (SET) the permanent SAS file "datafilename" in the "folder" location  */

	DATA work.datafilename;
		SET filepath.datafilename;
	RUN;
	
* This code is equivalent -- if you dont specify a library, it goes to "work";

	DATA datafilename;
		SET filepath.datafilename;
	RUN;


**************************************************
***   Saving SAS datasets to permanent files   ***
**************************************************;

/* Note that you don't really ever need to do this, but here's how
   DATA creates a SAS data set in the permanent library called "datafileout"
   FROM (SET) the existing SAS file "datafilename" in the "work" location  */

	DATA filepath.datafileout;
		SET work.datafilename;
	RUN;


*****************************************************************************
*** OPTIONS FOR READING IN SPSS FILES IN ORDER OF PAINLESSNESS:
*** 1. Use PROC IMPORT
*** 2. Save SPSS .sav file as .sas7bdat file, read in as sas file (see above)
*** 3. Save SPSS .sav file as .por SPSS file, read in using SPSS library
******************************************************************************;


*************************************************
*** 1. Reading in SPSS .SAV Files directly    ***
*************************************************;

/* This creates a new SAS data set in the work library called "spssfile"
   from the .SAV file in the DATAFILE= location 
   "REPLACE" means write over it if it already exists
   Note: sometimes the value labels get imported in a format */

* Hard-coded path;
	PROC IMPORT DATAFILE = "F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\spssfile.sav"			            
            OUT=work.spssfile DBMS=SAV REPLACE;
	RUN;
* Abbreviated path;
	PROC IMPORT DATAFILE = "&filepath.\spssfile.sav"			            
            OUT=work.spssfile DBMS=SAV REPLACE;
	RUN;


* By default SAS uses the value labels as formats in the data;
* This can cause problems with how the values themselves are used in analyses;
* To fix it, save it as itself and add a FORMAT statement that shuts off all formats;
* The keyword _ALL_ refers to all variables in the file, or you can list certain variables;
	DATA work.spssfile; 
		SET work.spssfile; 
		FORMAT _ALL_; 
	RUN;

* To print what formats for value labels were imported, use this;
	PROC FORMAT FMTLIB LIB=work.formats; 
	RUN;
* To save formats to a SAS dataset, use this;
	PROC FORMAT CNTLOUT=work.DataFormats LIB=work.formats; 
	RUN;

******************************************
*** 3. Reading in SPSS Portable Files  ***
******************************************;

/* Although one can save SPSS .sav files as SAS files in the newer 
   versions of SPSS, I have not had any luck getting those files 
   to read correctly, so I'd recommend using portable SPSS files instead. 
   SPSS portable file names need to be 8 characters or less.
   All variable names must be 8 characters or less, too. 

   Note key word "SPSS" on LIBNAME statement below.
   This is a different kind of library statement, because it refers to
   both a PLACE and a .por file NAME, not just a place (as usual in LIBNAME).
   Thus, you need a new SPSS libname statement for EACH SPSS portable file.  

   LIBNAME defines the "spsslib" location and the .por file to be imported
   DATA creates a new SAS data set in the work library called "spssfile"
   FROM (SET) the .por file "spssfile" from "spsslib" location  */
   
* Hard-coded path;
	LIBNAME spsslib SPSS "F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\porfile.por";
	DATA work.porfile;					
		SET spsslib.porfile;	
	RUN;
* Abbreviated path;
	LIBNAME spsslib SPSS "&filepath.\porfile.por";
	DATA work.porfile;					
		SET spsslib.porfile;	
	RUN;


/* NOTE THAT SAVING IS NOT REQUIRED -- it happens immediately by default! */
/* No need to export SAS files as SPSS files -- SPSS can open them directly */

***************************************
***   Reading in Excel Worksheets   ***
***************************************;

/* This creates a new SAS data set in the work library called "excelfile"
   from the Excel workbook in DATAFILE= location from SHEET= 
   "REPLACE" means write over it if it already exists.
   "GETNAMES" reads in the first row as variable names. */

* Hard-coded path;
	PROC IMPORT DATAFILE = "F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\excelfile.xls" 
			OUT=work.excelfile DBMS=EXCEL REPLACE; 
		SHEET="sheetname"; GETNAMES=YES; 
	RUN;
* Abbreviated path;
	PROC IMPORT DATAFILE = "&filepath.\excelfile.xls" 
			OUT=work.excelfile DBMS=EXCEL REPLACE; 
		SHEET="sheetname"; 
		GETNAMES=YES; 
	RUN;

* This may work in v. 9.3, but I havent tested in yet;
	PROC IMPORT DATAFILE="F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\excelfilex.xlsx" 
			OUT=work.excelfilex DBMS=XLSX REPLACE; 
		SHEET="sheetname"; 
		GETNAMES=YES; 
	RUN;

************************************************
***   Exporting data out of SAS into Excel   ***
************************************************;

/* DATA lists file to be exported
   OUTFILE lists name and location of new file */

* Hard-coded path;
	PROC EXPORT 
		DATA=work.excelfilename  
			OUTFILE= "F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\FromSAStoExcel.xls" 
    		DBMS=EXCEL5 REPLACE; 
	RUN;
* Abbreviated path;
	PROC EXPORT 
		DATA=work.excelfile  
			OUTFILE= "&filepath.\FromSAStoExcel.xls" 
    		DBMS=EXCEL5 REPLACE; 
	RUN;


****************************************************************
***   Importing/Exporting Excel if engine is not installed   ***
****************************************************************;

* Certain versions of SAS do not permit the IMPORT/EXPORT procedures to be used
   with excel. In that case, it is best to save the excel file as a .csv file,
   a comma-delimited file, and import/export it in that format instead. */

***** TO IMPORT A CSV FILE;
* Hard-coded path;
	PROC IMPORT DATAFILE = "F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\csvfile.csv" 
			OUT=work.csvfile DBMS=CSV REPLACE;  
		GETNAMES=YES;   * Select NO if there are no names on the top row;
		DATAROW=2;		* Which row to start importing from;
	RUN;
* Abbreviated path;
	PROC IMPORT DATAFILE = "&filepath.\csvfile.csv" OUT=work.csvfile DBMS=CSV REPLACE;  
		GETNAMES=YES; 
	RUN;


***** TO EXPORT TO A CSV FILE;
* Hard-coded path;
	PROC EXPORT DATA=work.excelfile OUTFILE="F:\12_ICPSR\ICPSR_2012_Download\SAS\Activity1\file2csv.csv" 
		DBMS=CSV REPLACE; 
	RUN;
* Abbreviated path;
	PROC EXPORT DATA=work.excelfile OUTFILE="&filepath.\file2excel.xls" 
		DBMS=CSV REPLACE; 
	RUN;


********************
*** Sorting Data ***
********************;

/* Just like other programs, files must be sorted in same order
   prior to combining or merging. It's a good idea to just include
   this by default prior to any merging just in case. */

	PROC SORT DATA=work.datafilename; 
		BY ID; 
	RUN;

/* Using PROC SORT to eliminate duplicates: 
   NODUPKEY = all observations with the same BY values will be deleted.
   Sorted, non-duplicate dataset is saved via OUT as "datafilename2" 
   Duplicate cases get saved via DUPOUT into "duplicates" instead */
	PROC SORT DATA=work.datafilename NODUPKEY 
			OUT=work.datafilename2 DUPOUT=work.duplicates; 
		BY var1 var2; 
	RUN;


***********************************************************
*** 	Renaming, trimming, and labeling variables 		***
***********************************************************;

/* The following commands can be used in DATA steps:
	RENAME	renames existing variables
	KEEP	keeps listed variables (but does not re-order)
	DROP	drops listed variables
	RETAIN	re-orders variables as listed in file
			must be used immediately after DATA command */

/* Variable labels must be added within a DATA step
   Value labels are not stored with data, are are defined elsewhere */

* Using DATA + SET is like "save as itself";

* We rename existing variables, keep some, drop others;
* KEEP and DROP are mutually exclusive;
	DATA work.datafilename; 
		SET work.datafilename; 
		KEEP var1 var2 newvar1 newvar2;
		DROP var3 var4;		
		RENAME oldvar1=newvar1 oldvar2=newvar2; 
	RUN;

/*	Can abbreviate lists of variables for KEEP and DROP two ways:
		"-"  refers to variables numerically
		"--" refers to variables positionally	
	var1-var50 refers to var1, var2, var3...var50
	var1--var50 refers to var1, (next var in file)... var50 */

* We can use RETAIN to re-order variables in file;
* Any variables not listed on RETAIN get same place in file;
* RETAIN must be used IMMEDIATELY after the DATA command;
* Here, we want "firstvar" first and "lastvar" to be second;
* All other variables get put after it in original order;
	DATA work.datafilename;
		RETAIN firstvar secondvar;
		SET work.datafilename;
	RUN;


*******************************************************************************
****** 				Merging Files and Restructuring Data 				 ******
******************************************************************************;

/* It is ALWAYS a good idea to sort data sets before any kind of merge */

***************************************************
*** 	Adding CASES (rows) to a data file 		***
***************************************************;

/* DATA step names file to be created from merged datasets.
   SET lists datasets to be combined when ADDING CASES.
   If variables differ, those cases without will get missing values.
   Observations will be ordered by IDvar */

	PROC SORT DATA=work.cases1; 
		BY IDvar; 
	RUN;
	PROC SORT DATA=work.cases2; 
		BY IDvar; 
	RUN;
	DATA work.allcases; 
		SET work.cases1 work.cases2; 
		BY IDvar; 
	RUN; 


*******************************************************
*** 	Adding VARIABLES (columns) to a data file 	***
*******************************************************;

/* DATA step names file to be created from merged datasets.
   MERGE lists datasets to be combined when ADDING VARIABLES.
   Cases will be merged BY IDvar. (can add other variables, too)
   If there are common variables across datasets, 2nd will overwrite 1st.	
   Each file MUST be sorted by IDvar first. */

	PROC SORT DATA=work.vars1; 
		BY IDvar; 
	RUN;
	PROC SORT DATA=work.vars2; 
		BY IDvar; 
	RUN;
	DATA work.allvars; 
		MERGE work.vars1 work.vars2; 
		BY IDvar; 
	RUN; 


*******************************************************
*** 	Updating a MASTER data file with new data 	***
*******************************************************;

/* UPDATE statements updates first dataset with second dataset.
   Missing data from "newfile1" file do not overwrite values in master.
   Data from "newfile2" would then be added where needed, and so on.
   Must be sorted by IDvar 1st; IDvar must be unique in master */

	PROC SORT DATA=work.master;   
		BY IDvar; 
	RUN;
	PROC SORT DATA=work.newfile1; 
		BY IDvar; 
	RUN;
	PROC SORT DATA=work.newfile2; 
		BY IDvar; 
	RUN;
	DATA work.newestdata; 
		UPDATE work.master work.newfile1 work.newfile2; 
		BY IDvar; 
	RUN; 


***********************************************************************
*** 	Go from MULTIVARIATE (wide) data to STACKED (long) data 	***
***********************************************************************;

/* Creates stacked variables wave, IV, and DV for each time point. 
   All other variables are copied down be default.
   Must include all variables per time point on same line before OUTPUT. 
   OUTPUT then writes the new line of data.
   Note: all old multivariate variables get included still. */

	PROC IMPORT DATAFILE="&filepath.\multivprac.sav" 
		OUT=work.multivprac DBMS=SAV REPLACE;
	RUN;
	DATA work.stackprac; 
		SET work.multivprac;
			wave=1; DV=DVTime1; age=AgeTime1; OUTPUT;	 
			wave=2; DV=DVTime2; age=AgeTime2; OUTPUT;	
			wave=3; DV=DVTime3; age=AgeTime3; OUTPUT;		
			wave=4; DV=DVTime4; age=AgeTime4; OUTPUT; 
		LABEL wave= "wave: occasion of measurement"
				DV= "DV: New Dependent Variable over time"
				age= "age: New Age over time";
  /* The original multivariate variables are still in the file, unlike SPSS.
   Deleting them is unnecessary, but if you wanted to, here is how: */
		* Demonstrating numeric abbreviation -;
			* DROP DVTime1-DVTime4 AgeTime1-AgeTime4;
		* Demonstrating positional abbreviation --;
			* DROP DVTime1--AgeTime4;
	RUN; 

*******************************************************
*** 	Aggregating/summarizing data across rows 	***
*******************************************************;

/* PROC MEANS can be used to create summary data across observations.
   BY gives you a summary per unique value.
   NOPRINT suppresses output -- it is unnecessary here. 
   VAR lists variables to be summarized.
   OUTPUT OUT= lists datafile new summary variables get saved to.
   Many available functions: MEAN, STD, SUM, MIN, MAX, N, NMISS... 
   Format: FUNCTION(variable names) = new variable names */

* Data MUST be sorted with the BY variable first;
	PROC SORT DATA=work.datafilename; 
		BY IDvar; 
	RUN;
	PROC MEANS NOPRINT DATA=work.datafilename; 
		BY IDvar;				* Summary per value of IDvar;
		VAR var1 var2; 			* Do it for these variables;	
		OUTPUT OUT=work.summaryfile
			MAX (var1 var2) = var1mx var2mx	
			MEAN(var1 var2) = var1mn var2mn		
			STD (var1 var2) = var1sd var2sd
			N   (var1 var2) = var1n  var2n;	 * New variables;
	RUN;

* Merging summary file back into original data;
	DATA work.datafilename;
		MERGE work.datafilename work.summaryfile;
		BY ID;
	* Dropping unnecessary variables in summary data created by PROC MEANS;
		DROP _TYPE_ _FREQ_;
	RUN;


*******************************************************************************
****** 		            Adding Information about Your Variables			 ******
******************************************************************************;

* Adding meta data to variables must be done in a DATA step (dont forget SET)
  this is like "save as itself" when modifying a dataset;

* ALWAYS add variable labels to newly created variables;
	DATA work.datafile; 
		SET work.datafile;
		LABEL newvar= "newvar: Lesa's Label of New Variable";
	RUN;

* There is no such thing as value labels in SAS;
* Use PROC FORMAT instead;

* There is no such thing as missing value codes in SAS -- leave it blank;

* Rename variables as needed (also can be done when saving a dataset);
	DATA work.datafile; 
		SET work.datafile;
		RENAME oldvar1=newvar1 oldvar2=newvar2;
		* Labels still refer to OLD variable name (RENAME is processed last);
		LABEL oldvar1= "newvar1: Label of New Variable1"
			  oldvar2= "newvar2: Label of New Variable2";
	RUN;

*******************************************************************************
*******			     WAYS OF DESCRIBING/SUMMARIZING DATA			    *******
******************************************************************************;

* To print sample descriptive statistics for continuous variables;
	TITLE "Descriptive Statistics for My Continuous Variables";
	PROC MEANS N MEAN STDDEV MIN MAX SKEW KURTOSIS DATA=work.datafilename;
		VAR var1 var2 var4-var10;
    RUN;

* To print frequency tables;
 	TITLE "Descriptive Statistics for My Grouping Variables";
	PROC FREQ DATA=work.datafile;
		TABLE catvar1 catvar2 catvar1*catvar2;  * Use of "*" gives crosstab;
	RUN;



****************** Critical Point ******************************;
* Transformations must happen within a DATA step: use DATA + SET;
* If you forget the SET, you will create an empty file!;
****************************************************************;


*******************************************************************************
*******			CONDITIONAL LOGIC FOR CREATING VARIABLES				*******
******************************************************************************;

* IF-THEN allows for conditional processing;
* If you want to include more than one statement, use IF-THEN-DO-END;
* Make sure to put ' ' around string variable characters;
* Use parentheses to make sure expression is read as intended;
* "IF" gets paired with other relationsal operators such as:
	"equal to"					=	EQ
 	"not equal to"				~=	NE	
	"less than"					<	LT
	"less than or equal to"		<= 	LE
	"greater than"				>	GT
	"greater than or equal to"	>=	GE

	"and"						&	AND
	"or"						|	OR
	"not"						~	NOT	;


*******************************************************************************
*******				NUMERIC VARIABLE TRANSFORMATIONS					*******
******************************************************************************;

* These transformations can be used if all values necessary are in the same row;
* If summarizing across rows, you'll need PROC MEANS instead (see day 2);

* There is no RECODE in SAS - you have to use IF-THEN-DO-ELSE yourself;
* You can compute new variables, but you don't need the word COMPUTE;

* Transformations must happen within a DATA step: use DATA + SET;
* If you forget the SET, you will create an empty file!;
	DATA work.datafilename; SET work.datafilename;

* There are different ways to refer to a series of variables;
* Dont forget the "OF" or it will try to subtract them;
		meanvar = MEAN(OF var1, var2, var3, var4);	* long way;
		meanvar = MEAN(OF var1-var4);				* contiguous names;
		meanvar = MEAN(OF var1--var4);				* contiguous positions;
		LABEL meanvar= "meanvar: Mean of Var1-Var4";

* NMISS returns number missing rsponses for numeric variables; 
* N returns number of valid responses for numeric variables;
		nmiss10  = NMISS(OF var1--var10);
		nvalid10 = N(OF var1--var10);
		LABEL nmiss10= "nmiss10: Number Missing for Var1-10"
			  nval10=  "nval10: Number Answered for Var1-10";

* There is no direct way to specify minimum number to be computed;
* NMISS function can count number of missing values and IF to select;
* N function can count number of valid values and IF to select;
		IF NMISS(OF var1-var4) LE 1 THEN DO; 
			meanvar = MEAN(OF var1-var4); maxvar = MAX(OF var1-var4); END;
		ELSE DO; 
			meavar = .; maxvar = .; END;
		IF N(OF var1-var4) GE 3 THEN DO; 
			meanvar = MEAN(OF var1-var4); maxvar = MAX(OF var1-var4); END;
		ELSE DO; 
			meavar = .; maxvar = .; END;
		LABEL meanvar= "meanvar: Mean of Var1-Var4 (if at least 3)"
			  maxvar= "maxvar: Max of Var1-Var4 (if at least 3)";

* Note this is NOT equivalent to the code below;
* When using operators, if ANY are missing, the meavar will be missing;
		meanvar = (var1 + var2 + var3 + var4) / 4;
		LABEL meanvar= "meanvar: Mean of Var1-Var4 (only if all 4)";

 * Example of centering a continuous predictor at 50;
		c_pred = pred - 50;
		LABEL c_pred= "c_pred: Predictor Centered at 50 (0=50)";

* Hundreds of other possible functions;
* Functions can include variables or numeric constants as needed;
* Here are some more types of transformation;
		newvar = oldvar**2;   			* squaring old variable to make new;
		logvar = LOG(var);  			* taking natural log;
		log10var = LOG10(var);  		* taking log-base 10;
		maxvar = MAX(var);				* maximum value;
		minvar = MIN(var);				* minimum value;
		sumvar = SUM(OF var1, var2);	* sum of old variables;
		stdvar = STD(OF var1, var2);    * standard deviation of variables;

* Computing dummy variables;
* This code creates three new dummies where 0=no, 1=yes;
		white = (race=1);
		black = (race=2);
		other = (race=3);
		LABEL
			white= "white: Is White (0=no, 1=yes)"
			black= "black: Is Black (0=no, 1=yes)"
			other= "other: Is Other (0=no, 1=yes)";

* Example of reverse coding via IF-THEN-ELSE;
* Specify missing values first;
* To do this for more than one variable at a time, use an ARRAY;
		     IF (var1=.) THEN rvar1=.;
		ELSE IF (var1=5) THEN rvar1=1;
		ELSE IF (var1=4) THEN rvar1=2;
		ELSE IF (var1=3) THEN rvar1=3;
		ELSE IF (var1=2) THEN rvar1=4;
		ELSE IF (var1=1) THEN rvar1=5;
		ELSE rvar1=.;
		LABEL rvar1= "rvar1: Var1 Reverse-Coded";

* Example of creating categories from a continuous variable;
* missing or <1 = missing, 1 to 1.5 = 1, 1.51 to highest = 2;
* The "." = system missing;
	DATA work.datafilename; SET work.datafilename;
		     IF var1 = .     					THEN DO; catvar1 = .; END;
		ELSE IF var1 LE 0.99  				  	THEN DO; catvar1 = .; END;
		ELSE IF var1 GT 0.99 AND var1 LE 1.50 	THEN DO; catvar1 = 1; END;
		ELSE IF var1 GT 1.50 				 	THEN DO; catvar1 = 2; END;
		ELSE DO; var1 = catvar1; END;
		LABEL catvar1= "catvar1: Var1 1=1.0-1.5, 2=1.50+";
	RUN;

******* Other useful functions;

* Saving row number as permanent variable using _N_ keyword;
		IDvar = _N_;

* The IN function searches a variable for a series of possible values;
* This gives the variable 'pick2468' a value of 1 if var1 = 2 or 4 or 6 or 8;
	IF var1 IN(2,4,6,8) THEN pick2468=1; ELSE pick2468=0;
	LABEL pick2468= "pick2468: Var1=2,4,6,or8 (0=no, 1=yes)";

* The ROUND function can be used to round continuous variables;
	roundyr = ROUND(year,10);
	LABEL roundyr= "roundyr: Year Rounded to Nearest Decade";

* Don't forget the "run" that closes the data step;
	RUN;


*******************************************************************************
*******				WAYS OF SELECTING CASES TO USE						*******
******************************************************************************;

* The WEIGHT command can be used in PROCs to weight cases;
	PROC MEANS DATA=work.datafilename; 
		VAR var1 var2;
		WEIGHT surveywt;
	RUN;

* The BY statement is like SPLIT FILE -- run analyses per level of BY variable;
* Data MUST be sorted using the BY variable first;
	PROC SORT DATA=work.datafilename; 
		BY sex; 
	RUN;
	PROC MEANS DATA=work.datafilename; 
		BY sex;				* Get means for boys and girls separately;
		VAR var1 var2;		* Get means for these variables;
	RUN;


* WHERE statement is like FILTER;
* WHERE can appear after any DATA or PROC statement 
  to select observations using conditional operators: EQ, NE, GT, LT, 
  GE, LE, AND, OR, IS NOT MISSING, BETWEEN AND, CONTAINS 'string';

* This creates a file with only cases where Sex=1 and race=3;
	DATA work.girlsonly; 
		SET work.olddata;
		WHERE Sex=1 AND race=3;
	RUN;

* Here is another way to do the same thing using IF instead of WHERE;
	DATA work.girlsonly; 
		SET work.olddata;
		IF Sex=1;
	RUN;

* Here is an example of using WHERE and NMISS to include only complete cases; 
	DATA work.complete; 
		SET work.olddata;
		WHERE NMISS(var1, var2)=0;
	RUN;
