* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for files to be saved - CHANGE THIS;
%LET example= F:\12_ICPSR\ICPSR_2012_Download\SAS;
LIBNAME example "&example.";

* Open SAS stacked version of ANOVA data into work (temporary) library;
* Mean-centering predictors for analysis;
DATA work.Stacked; SET example.Example1_Stacked; 
	ageM = age - 10.5;
	treatM = treat - .5;
	ageXtreat = ageM * treatM;
	LABEL ageM = "Age (0=10.5 mean)"
		  treatM = "Treatment Group (0=.5 mean)"
		  ageXtreat = "Age by Treatment Interaction (0=means)";
RUN;

* SAS example of Between-Person model via General Linear Model;
PROC GLM DATA=work.Stacked;
	CLASS ageM treatM;
	MODEL y = ageM treatM ageM*treatM;
	LSMEANS ageM*treatM;
RUN; QUIT;

* SAS example of Between-Person model via Regression;
PROC REG DATA=work.Stacked;
	MODEL y = ageM treatM ageXtreat;
RUN; QUIT;

* SAS example of Between-Person model via MIXED;
PROC MIXED DATA=work.Stacked NOITPRINT COVTEST METHOD=REML;
	MODEL y = ageM treatM ageM*treatM / SOLUTION DDFM=BW;
RUN;

******************************************************************;

* Open SAS multivariate version of anova data into work library;
* Mean-centering predictor for analysis;
DATA work.Multiv; SET example.Example1_Multiv;
	treatM = treat - .5;
	LABEL treatM = "Treatment Group (0=.5 mean)";
RUN;

* SAS example of Within-Person model via RM GLM;
PROC GLM DATA=work.Multiv;
	CLASS treatM;
	MODEL y10 y11 = treatM / NOUNI;
	REPEATED age 2 / ;
	LSMEANS treatM;
RUN; QUIT;

* SAS example of Within-Person model via MIXED;
PROC MIXED DATA=work.Stacked NOCLPRINT NOITPRINT COVTEST METHOD=REML;
	CLASS PersonID;
	MODEL y = ageM treatM ageM*treatM / SOLUTION DDFM=BW;
	RANDOM INTERCEPT / SUBJECT=PersonID TYPE=UN;
RUN;


* How one would create a stacked version of the multivariate file in SAS;
DATA work.NewStacked; SET work.Multiv;
	age=10; y=y10; OUTPUT;
	age=11; y=y11; OUTPUT;
RUN;
