* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;

* Location for original SAS files for these models;
%LET filepath = F:\12_ICPSR\ICPSR_2012_Download\SAS;
LIBNAME filepath "&filepath.";
	
* SAS code to import data, center time for polynomial models;
DATA work.example35; SET filepath.example35;
	c1sess = Session - 1; 	LABEL c1sess = "c1sess: Session Centered at 1";
	c6sess = Session - 6; 	LABEL c6sess = "c6sess: Session Centered at 6";
RUN;

******************************************************************************
****** 						EXAMPLE 3 MODELS							******
******************************************************************************;

TITLE1 "SAS Model 1a: Empty Means, Random Intercept";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt =  / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / G V VCORR TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;

TITLE1 "SAS Model 1b: Saturated Means, Unstructured Variances";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = session / SOLUTION DDFM=Satterthwaite;
	REPEATED session / R RCORR TYPE=UN SUBJECT=ID;
	LSMEANS session /; RUN;

TITLE1 "SAS Model 2a: Fixed Linear Time, Random Intercept";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = c1sess / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / G V TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;

TITLE1 "SAS Model 2b: Random Linear Time";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = c1sess / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT c1sess / SOLUTION G V TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;

TITLE1 "SAS Model 3a: Fixed Quadratic, Random Linear Time";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = c1sess c1sess*c1sess / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT c1sess / G V VCORR TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;

TITLE1 "SAS Model 3b: Random Quadratic Time";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = c1sess c1sess*c1sess / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT c1sess c1sess*c1sess / G V VCORR TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; 
	* Predicting means from model for each session;
	ESTIMATE "Intercept at Session 1" 	intercept 1 c1sess 0 c1sess*c1sess 0;
	ESTIMATE "Intercept at Session 2" 	intercept 1 c1sess 1 c1sess*c1sess 1;
    ESTIMATE "Intercept at Session 3" 	intercept 1 c1sess 2 c1sess*c1sess 4;
	ESTIMATE "Intercept at Session 4" 	intercept 1 c1sess 3 c1sess*c1sess 9;
	ESTIMATE "Intercept at Session 5" 	intercept 1 c1sess 4 c1sess*c1sess 16;
	ESTIMATE "Intercept at Session 6" 	intercept 1 c1sess 5 c1sess*c1sess 25;
	* Predicting linear rate of change at each session (linear changes by 2*quad);
	ESTIMATE "Linear Slope at Session 1" c1sess 1 c1sess*c1sess 0;
	ESTIMATE "Linear Slope at Session 2" c1sess 1 c1sess*c1sess 2;
	ESTIMATE "Linear Slope at Session 3" c1sess 1 c1sess*c1sess 4;
	ESTIMATE "Linear Slope at Session 4" c1sess 1 c1sess*c1sess 6;
	ESTIMATE "Linear Slope at Session 5" c1sess 1 c1sess*c1sess 8;
	ESTIMATE "Linear Slope at Session 6" c1sess 1 c1sess*c1sess 10; RUN;

* Changing centering to session 6;

TITLE1 "SAS Model 3a: Fixed Quadratic, Random Linear Time (6=0)";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = c6sess c6sess*c6sess / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT c6sess / G V VCORR TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;

TITLE1 "SAS Model 3b: Random Quadratic Time (6=0)";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 METHOD=REML;
	CLASS ID session;
	MODEL nm3rt = c6sess c6sess*c6sess / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT c6sess c6sess*c6sess / G V VCORR TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;


******************************************************************************
****** 						EXAMPLE 5 MODELS							******
******************************************************************************;

* Centering level-2 predictor variables for analysis;
DATA work.example35; SET work.example35;
	age80  = age - 80; 		* Convenient value;
	reas22 = absreas - 22;	* Near sample mean;		
	LABEL age80  = "age80: Age Centered (0=80)" 
	      reas22 = "reas22: Abstract Reasoning Centered (0=22)"; 
	* Make education a grouping variable for purpose of demonstration only;
	     IF educyrs LE 12                   THEN educgrp=1;
	ELSE IF educyrs GT 12 AND EducYrs LE 16 THEN educgrp=2;
	ELSE IF educyrs GT 16                   THEN educgrp=3;
	ELSE IF educyrs = .                     THEN educgrp=.;
	LABEL educgrp = "educgrp: Education Group (1=HS, 2=BA, 3=GRAD)";
* Removing cases with missing predictors;
	IF NMISS(age80, reas22, educgrp)>0 THEN DELETE;
RUN;

TITLE1 "SAS Model 3b: Random Quadratic Time Baseline in ML";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS ID session;
	MODEL nm3rt = c1sess c1sess*c1sess / SOLUTION DDFM=Satterthwaite OUTPM=work.TimePred;
	RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR V VCORR TYPE=UN SUBJECT=ID;
	REPEATED session / R TYPE=VC SUBJECT=ID; RUN;
PROC CORR NOSIMPLE DATA=work.TimePred; VAR nm3rt pred; RUN;

TITLE1 "SAS Model 4a: Age as Predictor of Intercept, Linear, and Quadratic";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS ID session;
	MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80 
					/ SOLUTION DDFM=Satterthwaite OUTPM=work.AgePred;
	RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID;
	REPEATED session / TYPE=VC SUBJECT=ID; 
	* Requesting additional effects for age;
	ESTIMATE "Age Effect at Session 1" age80 1 c1sess*age80 0 c1sess*c1sess*age80 0;
	ESTIMATE "Age Effect at Session 2" age80 1 c1sess*age80 1 c1sess*c1sess*age80 1;
	ESTIMATE "Age Effect at Session 3" age80 1 c1sess*age80 2 c1sess*c1sess*age80 4;
	ESTIMATE "Age Effect at Session 4" age80 1 c1sess*age80 3 c1sess*c1sess*age80 9;
	ESTIMATE "Age Effect at Session 5" age80 1 c1sess*age80 4 c1sess*c1sess*age80 16;
	ESTIMATE "Age Effect at Session 6" age80 1 c1sess*age80 5 c1sess*c1sess*age80 25; 
RUN; PROC CORR NOSIMPLE DATA=work.AgePred; VAR nm3rt pred; RUN;

TITLE1 "SAS Model 5a: +Reasoning as Predictor of Intercept, Linear, and Quadratic";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS ID session;
	MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
			 	  reas22 c1sess*reas22 c1sess*c1sess*reas22 
						/ SOLUTION DDFM=Satterthwaite OUTPM=work.ReasPred;
	RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID; 
	REPEATED session / TYPE=VC SUBJECT=ID;
RUN; PROC CORR NOSIMPLE DATA=work.ReasPred; VAR nm3rt pred; RUN;

TITLE1 "SAS Model 5b: Reasoning on Intercept and Linear Time Slope Only";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS ID session;
	MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
			 	  reas22 c1sess*reas22   
			/ SOLUTION DDFM=Satterthwaite OUTPM=work.ReasPred2;
	RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID; 
	REPEATED session / TYPE=VC SUBJECT=ID;
	* Requesting additional effects for reasoning instead;
	ESTIMATE "Reasoning Effect at Session 1" reas22 1 c1sess*reas22 0;
	ESTIMATE "Reasoning Effect at Session 2" reas22 1 c1sess*reas22 1;
	ESTIMATE "Reasoning Effect at Session 3" reas22 1 c1sess*reas22 2;
	ESTIMATE "Reasoning Effect at Session 4" reas22 1 c1sess*reas22 3;
	ESTIMATE "Reasoning Effect at Session 5" reas22 1 c1sess*reas22 4;
	ESTIMATE "Reasoning Effect at Session 6" reas22 1 c1sess*reas22 5;
RUN; PROC CORR NOSIMPLE DATA=work.ReasPred2; VAR nm3rt pred; RUN;

TITLE1 "SAS Model 6a: +Education Group on Intercept, Linear, and Quadratic";
PROC MIXED DATA=work.example35 NOCLPRINT NOITPRINT COVTEST NAMELEN=100 IC METHOD=ML;
	CLASS ID session educgrp;
	MODEL nm3rt = c1sess c1sess*c1sess age80 c1sess*age80 c1sess*c1sess*age80
			 	  reas22 c1sess*reas22 
				  educgrp c1sess*educgrp c1sess*c1sess*educgrp 
					/ SOLUTION DDFM=Satterthwaite OUTPM=work.EducPred;
	RANDOM INTERCEPT c1sess c1sess*c1sess / G GCORR TYPE=UN SUBJECT=ID; 
	REPEATED session / TYPE=VC SUBJECT=ID;
	* LSMEANS gives follow-up tests and means per group for main effect only;
	LSMEANS educgrp  / AT (c1sess) = (0) DIFF=ALL; 
	LSMEANS educgrp  / AT (c1sess) = (5) DIFF=ALL; 
	* ESTIMATE statements can also give specific effects as before;
	ESTIMATE "L vs. H Educ for Intercept Main Effect"  educgrp -1  0  1 ;
	ESTIMATE "M vs. H Educ for Intercept Main Effect"  educgrp  0 -1  1 ;
	ESTIMATE "L vs. M Educ for Intercept Main Effect"  educgrp -1  1  0 ;
	ESTIMATE "L vs. H Educ for Linear Session"  c1sess*educgrp -1  0  1 ;
	ESTIMATE "M vs. H Educ for Linear Session"  c1sess*educgrp  0 -1  1 ;
	ESTIMATE "L vs. M Educ for Linear Session"  c1sess*educgrp -1  1  0 ;
	ESTIMATE "L vs. H Educ for Quadratic Session"  c1sess*c1sess*educgrp -1  0  1 ;	
	ESTIMATE "M vs. H Educ for Quadratic Session"  c1sess*c1sess*educgrp  0 -1  1 ;
	ESTIMATE "L vs. M Educ for Quadratic Session"  c1sess*c1sess*educgrp -1  1  0 ;
RUN; PROC CORR NOSIMPLE DATA=work.EducPred; VAR nm3rt pred; RUN;
