* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE example /NAME = "F:\12_ICPSR\ICPSR_2012_Download\SPSS".

* SPSS code to import data.
GET FILE = "example/Example8.sav".
DATASET NAME example8 WINDOW=FRONT.

* Getting means per primary school and secondary school of kid predictor.
SORT CASES BY pschool.
AGGREGATE /OUTFILE=* MODE=ADDVARIABLES /PRESORTED /BREAK = pschool /pmSES = MEAN(pupSES). 
SORT CASES BY sschool.
AGGREGATE /OUTFILE=* MODE=ADDVARIABLES /PRESORTED /BREAK = sschool /smSES = MEAN(pupSES).
VARIABLE LABELS pmSES "pmSES: Primary School SES"
	               smSES "smSES: Secondary School SES".
* Center and label predictors.
COMPUTE pupSES4 = pupSES - 4. 
COMPUTE pmSES4 = pmSES - 4.
COMPUTE smSES4 = smSES - 4.
VARIABLE LABELS pupSES4 "pupSES4: Student SES (0=4)"
			             pmSES4  "pmSES4: Primary School Mean SES (0=4)"
                smSES4  "smSES4: Secondary School Mean SES (0=4)".
EXECUTE.


******************************************************************************
****** 						                 EXAMPLE 8 MODELS							                   ******
******************************************************************************.

DATASET ACTIVATE example8 WINDOW=FRONT.

TITLE "SAS Model 1a: Empty Means, Random Intercept for Secondary School".
MIXED achiev BY sschool pschool
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = 
 /RANDOM = INTERCEPT | SUBJECT(sschool) COVTYPE(UN).

TITLE "SAS Model 1b: Add Random Intercept for Primary School (now crossed by Secondary)".
MIXED achiev BY sschool pschool
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = 
 /RANDOM = INTERCEPT | SUBJECT(sschool) COVTYPE(UN)
 /RANDOM = INTERCEPT | SUBJECT(pschool) COVTYPE(UN).

TITLE "SAS Model 2: Add Fixed Effects for School Denomination".
MIXED achiev BY sschool pschool WITH pdenom sdenom
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = pdenom sdenom
 /RANDOM = INTERCEPT | SUBJECT(sschool) COVTYPE(UN)
 /RANDOM = INTERCEPT | SUBJECT(pschool) COVTYPE(UN).

TITLE "SAS Model 3a: Add Fixed Effect of Pupil SES".
MIXED achiev BY sschool pschool WITH pdenom sdenom pupSES4
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = pdenom sdenom pupSES4
 /RANDOM = INTERCEPT | SUBJECT(sschool) COVTYPE(UN)
 /RANDOM = INTERCEPT | SUBJECT(pschool) COVTYPE(UN).

TITLE "SAS Model 3b: Add Pupil SES Contextual Effects".
MIXED achiev BY sschool pschool WITH pdenom sdenom pupSES4 pmSES4 smSES4
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = pdenom sdenom pupSES4 pmSES4 smSES4
 /RANDOM = INTERCEPT | SUBJECT(sschool) COVTYPE(UN)
 /RANDOM = INTERCEPT | SUBJECT(pschool) COVTYPE(UN).

TITLE "SAS Model 3c: Add Random Pupil SES Effect for Secondary School".
MIXED achiev BY sschool pschool WITH pdenom sdenom pupSES4 pmSES4 smSES4
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = pdenom sdenom pupSES4 pmSES4 smSES4
 /RANDOM = INTERCEPT pupSES4 | SUBJECT(sschool) COVTYPE(UN)
 /RANDOM = INTERCEPT         | SUBJECT(pschool) COVTYPE(UN).

TITLE "SAS Model 3d: Add Random Pupil SES Effect for Primary School".
MIXED achiev BY sschool pschool WITH pdenom sdenom pupSES4 pmSES4 smSES4
	/METHOD = REML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = pdenom sdenom pupSES4 pmSES4 smSES4
 /RANDOM = INTERCEPT pupSES4 | SUBJECT(sschool) COVTYPE(UN)
 /RANDOM = INTERCEPT pupSES4 | SUBJECT(pschool) COVTYPE(UN).


