************************************************************************************************
*****                         STATA MULTILEVEL MODELING SYNTAX		                      ******
************************************************************************************************


* GENERIC EXAMPLE SYNTAX FOR XTMIXED:
 	xtmixed DV fixed effects, FE options || Level2ID: random effects, RE options ///
	  	variance reml/mle covariance(Gmatrixtype) residuals(Rmatrixtype, t(Level1ID)),
	  	estat ic n(#persons),


* Fixed effects (FE) options: 
	* noconstant to remove fixed intercept (included by default)
	* i. indicates categorical predictors (reference is first by default)
	* c. indicates continuous predictors (default if not specified)
	* can fit interactions on the fly
		* c.age#c.age creates quadratic age slope
		* i.group#c.age creates group by age interaction
		* i.program##i.day creates program by day categorical interaction
* Random effects (RE) options: 
	* noconstant to remove random intercept (included by default)
	* covariance(Unstructured) is for G matrix unstructured
	* estat recovariance --> display G matrix
		* options: , level(levelvar) correlation
		* levelvar says at what level, correlation prints GCORR
	* Can add another level as || Level3ID: random effects, RE options
	* Can add group predictors of random effects heterogeneity
		* gen: boyXage = boy*age
		* ID: boy boyXage, no constant --> separate int and age slope per gender
	* Add R. to indicate categorical variables as random effects
	* Add _all: instead of ID: to indicate no nesting
	* Can do crossed models
		* || _all: R.id || _all: R.week --> persons by weeks as crossed
		* More efficient and equivalent: || _all: R.week || id:
* Residual options:
	* R matrix via residual(form,options)
		* independent-->VC, exchangeable-->CS, unstructured, toeplitz #-->TOEPn
		* AR #, exponential --> AR for unbalanced time
	* option by(varname) allows heterogeneous residual variance
	* option t(varname) is level-1 ID variable (i.e., for time)
* General options:
	* mle for ML, reml for REML is default
	* variance asks for variances rather than SD
	* noretable for no random effects solution 
	* nogroup for no table summarizing groups
	* noheader suppresses output header
* estat ic --> print AIC and BIC (where #parms = #total parms)

*** Other options

* estimates --> Can store results and do LR test comparisons 
* lrtest --> LR test for models listed that have been saved
	 estimates store bigmodel, estimates store smallmodel
	 lrtest bigmodel smallmodel

* lincom --> point estimates and SEs for linear combinations (like ESTIMATE)
	lincom  1*xvar + 3*xvar*zvar 		// Simple effect of X if Z=3
	lincom  1*zvar + 3*xvar*zvar 		// Simple effect of Z if X=3

* margins --> marginal means (LSMEANS)
* Estimating group means at first and last occasions
 	margins ib(last).catvar1,  at(c.time=(0) c.timesq=(0 ))
 	margins ib(last).catvar1,  at(c.time=(5) c.timesq=(25))
	
* predict --> predicted estimates, linear predictor and SE from fixed effects
	 predict xb 

* test --> Wald test of simple and composite linear hypotheses
* Example contrasts between groups on intercept and linear time slopes
 	test 1.catvar1=3.catvar1					// Low vs. High: Intercept
	test 2.catvar1=3.catvar1					// Med vs. High: Intercept
	test 1.catvar1=2.catvar1					// Low vs. Med:  Intercept
	test 1.catvar1#time=3.catvar1#time			// Low vs. High: Linear Slope
	test 2.catvar1#time=3.catvar1#time			// Med vs. High: Linear Slope
	test 1.catvar1#time=2.catvar1#time			// Low vs. Med:  Linear Slope

